@@ -1,5 +1,5 @@
 """All things audio."""
-from klang.audio.audio_files import *
+from klang.audio.wavfile import *
 from klang.audio.effects import *
 from klang.audio.envelopes import *
 from klang.audio.helpers import *
@@ -8,7 +8,6 @@ from klang.audio.mixer import *
 from klang.audio.oscillators import *
 from klang.audio.panning import *
 from klang.audio.sampling import *
-from klang.sequencer import *
 from klang.audio.sync import *
 from klang.audio.synthesizer import *
 from klang.audio.voices import *
