@@ -9,12 +9,16 @@ from klang.connections import MessageInput, MessageOutput
 class NoteLengthener(Block):
 
     """Convert note-ons to actual notes (note-on followed by a note-off later
-    on).
+    on in the future).
     """
 
     clock = time.time
+    """callable: Clock giver."""
 
     def __init__(self, duration):
+        """Args:
+            duration (float): Absolute note duration in seconds.
+        """
         super().__init__()
         self.inputs = [MessageInput(owner=self)]
         self.outputs = [MessageOutput(owner=self)]
@@ -38,9 +42,7 @@ class NoteLengthener(Block):
             self.output.send(noteOff)
 
         for note in self.input.receive():
-            if note.off:
-                continue
-
-            entry = (now + self.duration, note)
-            self.activeNotes.append(entry)
-            self.output.send(note)
+            if note.on:
+                entry = (now + self.duration, note)
+                self.activeNotes.append(entry)
+                self.output.send(note)
